==> dojo_1.15.4+dfsg1.orig.tar.xz: dojo-release-1.15.4-src/dojo/cldr/nls/zh-hant/generic.js <==
define(
//begin v1.x content
{
	"field-quarter-short-relative+0": "這一季",
	"field-quarter-short-relative+1": "下一季",
	"field-tue-relative+-1": "上週二",
	"field-year": "年",
	"dateFormatItem-Hm": "H:mm",
	"field-wed-relative+0": "本週三",
	"field-wed-relative+1": "下週三",
	"dateFormatItem-ms": "mm:ss",
	"field-minute": "分鐘",
	"field-tue-narrow-relative+0": "本週二",
	"field-tue-narrow-relative+1": "下週二",
	"field-thu-short-relative+0": "本週四",
	"dateTimeFormat-short": "{1} {0}",
	"field-thu-short-relative+1": "下週四",
	"field-day-relative+0": "今天",
	"field-day-relative+1": "明天",
	"field-day-relative+2": "後天",
	"field-wed-narrow-relative+-1": "上週三",
	"field-year-narrow": "年",
	"field-tue-relative+0": "本週二",
	"field-tue-relative+1": "下週二",
	"field-second-short": "秒",
	"dateFormatItem-MMMd": "M月d日",
	"field-week-relative+0": "本週",
	"field-month-relative+0": "本月",
	"field-week-relative+1": "下週",
	"field-month-relative+1": "下個月",
	"field-sun-narrow-relative+0": "本週日",
	"field-mon-short-relative+0": "本週一",
	"field-sun-narrow-relative+1": "下週日",
	"field-mon-short-relative+1": "下週一",
	"field-second-relative+0": "現在",
	"dateFormatItem-yyyyQQQ": "G y年QQQ",
	"field-month-short": "月",
	"dateFormatItem-GyMMMEd": "G y年M月d日 E",
	"dateFormatItem-yyyyMd": "G y/M/d",
	"field-day": "日",
	"field-year-relative+-1": "去年",
	"field-sat-short-relative+-1": "上週六",
	"field-hour-relative+0": "這一小時",
	"dateFormatItem-yyyyMEd": "G y/M/d（E）",
	"field-wed-relative+-1": "上週三",
	"dateTimeFormat-medium": "{1} {0}",
	"field-sat-narrow-relative+-1": "上週六",
	"field-second": "秒",
	"dateFormat-long": "G y年M月d日",
	"dateFormatItem-GyMMMd": "G y年M月d日",
	"field-quarter": "季",
	"field-week-short": "週",
	"field-tue-short-relative+0": "本週二",
	"field-tue-short-relative+1": "下週二",
	"field-mon-relative+-1": "上週一",
	"dateFormatItem-GyMMM": "G y年M月",
	"field-month": "月",
	"field-day-narrow": "日",
	"dateFormatItem-MMM": "LLL",
	"field-minute-short": "分鐘",
	"field-dayperiod": "上午/下午",
	"field-sat-short-relative+0": "本週六",
	"field-sat-short-relative+1": "下週六",
	"dateFormat-medium": "G y年M月d日",
	"dateFormatItem-yyyyMMMM": "G y年M月",
	"dateFormatItem-yyyyM": "G y/M",
	"field-second-narrow": "秒",
	"field-mon-relative+0": "本週一",
	"field-mon-relative+1": "下週一",
	"field-year-short": "年",
	"field-quarter-relative+-1": "上一季",
	"dateFormatItem-yyyyMMMd": "G y年M月d日",
	"field-sat-relative+-1": "上週六",
	"dateTimeFormat-long": "{1} {0}",
	"dateFormatItem-Md": "M/d",
	"field-hour": "小時",
	"dateFormat-full": "G y年M月d日 EEEE",
	"field-month-relative+-1": "上個月",
	"dateFormatItem-Hms": "H:mm:ss",
	"field-quarter-short": "季",
	"field-sat-narrow-relative+0": "本週六",
	"field-fri-relative+0": "本週五",
	"field-sat-narrow-relative+1": "下週六",
	"field-fri-relative+1": "下週五",
	"field-sun-short-relative+0": "本週日",
	"field-sun-short-relative+1": "下週日",
	"field-week-relative+-1": "上週",
	"field-quarter-short-relative+-1": "上一季",
	"field-quarter-relative+0": "這一季",
	"field-minute-relative+0": "這一分鐘",
	"field-quarter-relative+1": "下一季",
	"field-wed-short-relative+-1": "上週三",
	"dateFormat-short": "G y/M/d",
	"field-thu-short-relative+-1": "上週四",
	"dateFormatItem-yyyyMMMEd": "G y年M月d日 E",
	"field-mon-narrow-relative+-1": "上週一",
	"dateFormatItem-MMMMd": "M月d日",
	"field-thu-narrow-relative+-1": "上週四",
	"dateFormatItem-E": "ccc",
	"field-tue-narrow-relative+-1": "上週二",
	"dateFormatItem-H": "H時",
	"dateFormatItem-yyyy": "G y年",
	"field-wed-short-relative+0": "本週三",
	"dateFormatItem-M": "M月",
	"field-wed-short-relative+1": "下週三",
	"field-sun-relative+-1": "上週日",
	"dateTimeFormat-full": "{1}{0}",
	"dateFormatItem-hm": "ah:mm",
	"dateFormatItem-d": "d日",
	"field-weekday": "週天",
	"field-quarter-narrow-relative+0": "這一季",
	"field-sat-relative+0": "本週六",
	"field-quarter-narrow-relative+1": "下一季",
	"dateFormatItem-h": "ah時",
	"field-sat-relative+1": "下週六",
	"dateFormatItem-MEd": "M/d（E）",
	"dateFormatItem-y": "G y年",
	"field-thu-narrow-relative+0": "本週四",
	"field-thu-narrow-relative+1": "下週四",
	"field-sun-narrow-relative+-1": "上週日",
	"field-mon-short-relative+-1": "上週一",
	"field-thu-relative+0": "本週四",
	"field-thu-relative+1": "下週四",
	"dateFormatItem-hms": "ah:mm:ss",
	"field-fri-short-relative+-1": "上週五",
	"field-thu-relative+-1": "上週四",
	"field-week": "週",
	"dateFormatItem-Ed": "d E",
	"field-wed-narrow-relative+0": "本週三",
	"field-wed-narrow-relative+1": "下週三",
	"field-quarter-narrow-relative+-1": "上一季",
	"dateFormatItem-yyyyMMM": "G y年M月",
	"field-fri-short-relative+0": "本週五",
	"field-fri-short-relative+1": "下週五",
	"dateFormatItem-yyyyQQQQ": "G y年QQQQ",
	"field-hour-short": "小時",
	"field-month-narrow": "月",
	"field-hour-narrow": "小時",
	"field-fri-narrow-relative+-1": "上週五",
	"field-year-relative+0": "今年",
	"field-year-relative+1": "明年",
	"field-fri-relative+-1": "上週五",
	"field-tue-short-relative+-1": "上週二",
	"field-minute-narrow": "分鐘",
	"field-mon-narrow-relative+0": "本週一",
	"field-mon-narrow-relative+1": "下週一",
	"field-zone": "時區",
	"dateFormatItem-MMMEd": "M月d日 E",
	"field-quarter-narrow": "季",
	"field-sun-short-relative+-1": "上週日",
	"field-day-relative+-1": "昨天",
	"field-day-relative+-2": "前天",
	"field-sun-relative+0": "本週日",
	"field-sun-relative+1": "下週日",
	"dateFormatItem-Gy": "G y年",
	"field-day-short": "日",
	"field-week-narrow": "週",
	"field-era": "年代",
	"field-fri-narrow-relative+0": "本週五",
	"field-fri-narrow-relative+1": "下週五"
}
//end v1.x content
);

==> dojo_1.17.2+dfsg1.orig.tar.xz: dojo-release-1.17.2-src/dojo/cldr/nls/zh-hant/generic.js <==
define(
//begin v1.x content
{
	"field-quarter-short-relative+0": "這一季",
	"field-quarter-short-relative+1": "下一季",
	"field-tue-relative+-1": "上週二",
	"field-year": "年",
	"dateFormatItem-Hm": "H:mm",
	"field-wed-relative+0": "本週三",
	"field-wed-relative+1": "下週三",
	"dateFormatItem-ms": "mm:ss",
	"field-minute": "分鐘",
	"field-month-narrow-relative+-1": "上個月",
	"field-tue-narrow-relative+0": "本週二",
	"field-tue-narrow-relative+1": "下週二",
	"field-day-short-relative+-1": "昨天",
	"field-thu-short-relative+0": "本週四",
	"dateTimeFormat-short": "{1} {0}",
	"field-day-relative+0": "今天",
	"field-day-short-relative+-2": "前天",
	"field-thu-short-relative+1": "下週四",
	"field-day-relative+1": "明天",
	"field-week-narrow-relative+0": "本週",
	"field-day-relative+2": "後天",
	"field-week-narrow-relative+1": "下週",
	"dateFormatItem-EBhms": "E Bh:mm:ss",
	"field-wed-narrow-relative+-1": "上週三",
	"field-year-narrow": "年",
	"field-era-short": "年代",
	"field-year-narrow-relative+0": "今年",
	"field-tue-relative+0": "本週二",
	"field-year-narrow-relative+1": "明年",
	"field-tue-relative+1": "下週二",
	"field-weekdayOfMonth": "每月平日",
	"field-second-short": "秒",
	"dateFormatItem-MMMd": "M月d日",
	"field-weekdayOfMonth-narrow": "每月平日",
	"field-week-relative+0": "本週",
	"field-month-relative+0": "本月",
	"field-week-relative+1": "下週",
	"field-month-relative+1": "下個月",
	"field-sun-narrow-relative+0": "本週日",
	"field-mon-short-relative+0": "本週一",
	"field-sun-narrow-relative+1": "下週日",
	"field-mon-short-relative+1": "下週一",
	"field-second-relative+0": "現在",
	"dateFormatItem-yyyyQQQ": "G y年QQQ",
	"field-weekOfMonth": "週",
	"field-month-short": "月",
	"dateFormatItem-GyMMMEd": "G y年M月d日 E",
	"dateFormatItem-yyyyMd": "G y/M/d",
	"field-day": "日",
	"field-dayOfYear-short": "年天",
	"field-year-relative+-1": "去年",
	"field-sat-short-relative+-1": "上週六",
	"field-hour-relative+0": "這一小時",
	"dateFormatItem-yyyyMEd": "G y/M/d（E）",
	"field-second-short-relative+0": "現在",
	"field-wed-relative+-1": "上週三",
	"dateTimeFormat-medium": "{1} {0}",
	"field-sat-narrow-relative+-1": "上週六",
	"field-second": "秒",
	"dateFormatItem-Ehms": "E ah:mm:ss",
	"dateFormat-long": "G y年M月d日",
	"dateFormatItem-GyMMMd": "G y年M月d日",
	"field-hour-short-relative+0": "這一小時",
	"field-quarter": "季",
	"field-week-short": "週",
	"field-day-narrow-relative+0": "今天",
	"field-day-narrow-relative+1": "明天",
	"field-day-narrow-relative+2": "後天",
	"field-tue-short-relative+0": "本週二",
	"field-tue-short-relative+1": "下週二",
	"field-month-short-relative+-1": "上個月",
	"field-mon-relative+-1": "上週一",
	"dateFormatItem-GyMMM": "G y年M月",
	"field-month": "月",
	"field-day-narrow": "日",
	"dateFormatItem-MMM": "LLL",
	"field-minute-short": "分鐘",
	"field-dayperiod": "上午/下午",
	"field-sat-short-relative+0": "本週六",
	"field-sat-short-relative+1": "下週六",
	"dateFormat-medium": "G y年M月d日",
	"dateFormatItem-yyyyMMMM": "G y年M月",
	"dateFormatItem-yyyyM": "G y/M",
	"field-second-narrow": "秒",
	"field-mon-relative+0": "本週一",
	"field-mon-relative+1": "下週一",
	"field-day-narrow-relative+-1": "昨天",
	"field-year-short": "年",
	"field-day-narrow-relative+-2": "前天",
	"field-quarter-relative+-1": "上一季",
	"dateFormatItem-yyyyMMMd": "G y年M月d日",
	"field-dayperiod-narrow": "上午/下午",
	"field-week-narrow-relative+-1": "上週",
	"field-dayOfYear": "年天",
	"field-sat-relative+-1": "上週六",
	"dateTimeFormat-long": "{1} {0}",
	"dateFormatItem-Md": "M/d",
	"field-hour": "小時",
	"field-minute-narrow-relative+0": "這一分鐘",
	"dateFormat-full": "G y年M月d日 EEEE",
	"field-month-relative+-1": "上個月",
	"dateFormatItem-Hms": "H:mm:ss",
	"field-quarter-short": "季",
	"field-sat-narrow-relative+0": "本週六",
	"field-fri-relative+0": "本週五",
	"field-sat-narrow-relative+1": "下週六",
	"field-fri-relative+1": "下週五",
	"dateFormatItem-EBhm": "E Bh:mm",
	"field-month-narrow-relative+0": "本月",
	"field-month-narrow-relative+1": "下個月",
	"field-sun-short-relative+0": "本週日",
	"field-sun-short-relative+1": "下週日",
	"field-week-relative+-1": "上週",
	"field-quarter-short-relative+-1": "上一季",
	"dateFormatItem-Ehm": "E ah:mm",
	"field-minute-short-relative+0": "這一分鐘",
	"field-quarter-relative+0": "這一季",
	"field-minute-relative+0": "這一分鐘",
	"field-quarter-relative+1": "下一季",
	"field-wed-short-relative+-1": "上週三",
	"dateFormat-short": "G y/M/d",
	"dateFormatItem-Bh": "Bh時",
	"field-year-narrow-relative+-1": "去年",
	"field-thu-short-relative+-1": "上週四",
	"dateFormatItem-yyyyMMMEd": "G y年M月d日 E",
	"field-mon-narrow-relative+-1": "上週一",
	"dateFormatItem-MMMMd": "M月d日",
	"field-thu-narrow-relative+-1": "上週四",
	"dateFormatItem-E": "ccc",
	"dateFormatItem-H": "H時",
	"field-weekOfMonth-short": "週",
	"field-tue-narrow-relative+-1": "上週二",
	"dateFormatItem-yyyy": "G y年",
	"dateFormatItem-M": "M月",
	"field-wed-short-relative+0": "本週三",
	"field-wed-short-relative+1": "下週三",
	"field-sun-relative+-1": "上週日",
	"dateTimeFormat-full": "{1}{0}",
	"field-second-narrow-relative+0": "現在",
	"dateFormatItem-hm": "ah:mm",
	"dateFormatItem-d": "d日",
	"field-weekday": "週天",
	"field-day-short-relative+0": "今天",
	"field-quarter-narrow-relative+0": "這一季",
	"field-day-short-relative+1": "明天",
	"field-sat-relative+0": "本週六",
	"field-quarter-narrow-relative+1": "下一季",
	"dateFormatItem-h": "ah時",
	"field-day-short-relative+2": "後天",
	"field-sat-relative+1": "下週六",
	"field-week-short-relative+0": "本週",
	"field-week-short-relative+1": "下週",
	"field-dayOfYear-narrow": "年天",
	"field-month-short-relative+0": "本月",
	"field-month-short-relative+1": "下個月",
	"field-weekdayOfMonth-short": "每月平日",
	"dateFormatItem-MEd": "M/d（E）",
	"field-zone-narrow": "時區",
	"dateFormatItem-y": "G y年",
	"field-thu-narrow-relative+0": "本週四",
	"field-sun-narrow-relative+-1": "上週日",
	"field-mon-short-relative+-1": "上週一",
	"field-thu-narrow-relative+1": "下週四",
	"field-thu-relative+0": "本週四",
	"field-thu-relative+1": "下週四",
	"dateFormatItem-hms": "ah:mm:ss",
	"field-fri-short-relative+-1": "上週五",
	"field-thu-relative+-1": "上週四",
	"field-week": "週",
	"dateFormatItem-Ed": "d E",
	"field-wed-narrow-relative+0": "本週三",
	"field-wed-narrow-relative+1": "下週三",
	"field-quarter-narrow-relative+-1": "上一季",
	"field-year-short-relative+0": "今年",
	"dateFormatItem-yyyyMMM": "G y年M月",
	"field-dayperiod-short": "上午/下午",
	"field-year-short-relative+1": "明年",
	"field-fri-short-relative+0": "本週五",
	"field-fri-short-relative+1": "下週五",
	"field-week-short-relative+-1": "上週",
	"field-hour-narrow-relative+0": "這一小時",
	"dateFormatItem-yyyyQQQQ": "G y年QQQQ",
	"field-hour-short": "小時",
	"field-zone-short": "時區",
	"field-month-narrow": "月",
	"field-hour-narrow": "小時",
	"field-fri-narrow-relative+-1": "上週五",
	"field-year-relative+0": "今年",
	"field-year-relative+1": "明年",
	"field-era-narrow": "年代",
	"field-fri-relative+-1": "上週五",
	"dateFormatItem-Bhms": "Bh:mm:ss",
	"field-tue-short-relative+-1": "上週二",
	"field-minute-narrow": "分鐘",
	"field-mon-narrow-relative+0": "本週一",
	"dateFormatItem-EHm": "E HH:mm",
	"field-mon-narrow-relative+1": "下週一",
	"field-year-short-relative+-1": "去年",
	"field-zone": "時區",
	"dateFormatItem-MMMEd": "M月d日 E",
	"field-weekOfMonth-narrow": "週",
	"dateFormatItem-EHms": "E HH:mm:ss",
	"field-weekday-narrow": "週天",
	"field-quarter-narrow": "季",
	"field-sun-short-relative+-1": "上週日",
	"field-day-relative+-1": "昨天",
	"field-day-relative+-2": "前天",
	"field-weekday-short": "週天",
	"dateFormatItem-Bhm": "Bh:mm",
	"field-sun-relative+0": "本週日",
	"field-sun-relative+1": "下週日",
	"dateFormatItem-Gy": "G y年",
	"field-day-short": "日",
	"field-week-narrow": "週",
	"field-era": "年代",
	"field-fri-narrow-relative+0": "本週五",
	"field-fri-narrow-relative+1": "下週五"
}
//end v1.x content
);
